import datetime

from protos import ydb_operation_pb2 as _ydb_operation_pb2
from protos import ydb_scheme_pb2 as _ydb_scheme_pb2
from protos import ydb_status_codes_pb2 as _ydb_status_codes_pb2
from protos import ydb_issue_message_pb2 as _ydb_issue_message_pb2
from protos.annotations import sensitive_pb2 as _sensitive_pb2
from protos.annotations import validation_pb2 as _validation_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Codec(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    CODEC_UNSPECIFIED: _ClassVar[Codec]
    CODEC_RAW: _ClassVar[Codec]
    CODEC_GZIP: _ClassVar[Codec]
    CODEC_LZOP: _ClassVar[Codec]
    CODEC_ZSTD: _ClassVar[Codec]
    CODEC_CUSTOM: _ClassVar[Codec]

class AutoPartitioningStrategy(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    AUTO_PARTITIONING_STRATEGY_UNSPECIFIED: _ClassVar[AutoPartitioningStrategy]
    AUTO_PARTITIONING_STRATEGY_DISABLED: _ClassVar[AutoPartitioningStrategy]
    AUTO_PARTITIONING_STRATEGY_SCALE_UP: _ClassVar[AutoPartitioningStrategy]
    AUTO_PARTITIONING_STRATEGY_SCALE_UP_AND_DOWN: _ClassVar[AutoPartitioningStrategy]
    AUTO_PARTITIONING_STRATEGY_PAUSED: _ClassVar[AutoPartitioningStrategy]

class MeteringMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    METERING_MODE_UNSPECIFIED: _ClassVar[MeteringMode]
    METERING_MODE_RESERVED_CAPACITY: _ClassVar[MeteringMode]
    METERING_MODE_REQUEST_UNITS: _ClassVar[MeteringMode]
CODEC_UNSPECIFIED: Codec
CODEC_RAW: Codec
CODEC_GZIP: Codec
CODEC_LZOP: Codec
CODEC_ZSTD: Codec
CODEC_CUSTOM: Codec
AUTO_PARTITIONING_STRATEGY_UNSPECIFIED: AutoPartitioningStrategy
AUTO_PARTITIONING_STRATEGY_DISABLED: AutoPartitioningStrategy
AUTO_PARTITIONING_STRATEGY_SCALE_UP: AutoPartitioningStrategy
AUTO_PARTITIONING_STRATEGY_SCALE_UP_AND_DOWN: AutoPartitioningStrategy
AUTO_PARTITIONING_STRATEGY_PAUSED: AutoPartitioningStrategy
METERING_MODE_UNSPECIFIED: MeteringMode
METERING_MODE_RESERVED_CAPACITY: MeteringMode
METERING_MODE_REQUEST_UNITS: MeteringMode

class SupportedCodecs(_message.Message):
    __slots__ = ("codecs",)
    CODECS_FIELD_NUMBER: _ClassVar[int]
    codecs: _containers.RepeatedScalarFieldContainer[int]
    def __init__(self, codecs: _Optional[_Iterable[int]] = ...) -> None: ...

class OffsetsRange(_message.Message):
    __slots__ = ("start", "end")
    START_FIELD_NUMBER: _ClassVar[int]
    END_FIELD_NUMBER: _ClassVar[int]
    start: int
    end: int
    def __init__(self, start: _Optional[int] = ..., end: _Optional[int] = ...) -> None: ...

class UpdateTokenRequest(_message.Message):
    __slots__ = ("token",)
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: str
    def __init__(self, token: _Optional[str] = ...) -> None: ...

class UpdateTokenResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PartitionWithGeneration(_message.Message):
    __slots__ = ("partition_id", "generation")
    PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
    GENERATION_FIELD_NUMBER: _ClassVar[int]
    partition_id: int
    generation: int
    def __init__(self, partition_id: _Optional[int] = ..., generation: _Optional[int] = ...) -> None: ...

class MetadataItem(_message.Message):
    __slots__ = ("key", "value")
    KEY_FIELD_NUMBER: _ClassVar[int]
    VALUE_FIELD_NUMBER: _ClassVar[int]
    key: str
    value: bytes
    def __init__(self, key: _Optional[str] = ..., value: _Optional[bytes] = ...) -> None: ...

class StreamWriteMessage(_message.Message):
    __slots__ = ()
    class FromClient(_message.Message):
        __slots__ = ("init_request", "write_request", "update_token_request")
        INIT_REQUEST_FIELD_NUMBER: _ClassVar[int]
        WRITE_REQUEST_FIELD_NUMBER: _ClassVar[int]
        UPDATE_TOKEN_REQUEST_FIELD_NUMBER: _ClassVar[int]
        init_request: StreamWriteMessage.InitRequest
        write_request: StreamWriteMessage.WriteRequest
        update_token_request: UpdateTokenRequest
        def __init__(self, init_request: _Optional[_Union[StreamWriteMessage.InitRequest, _Mapping]] = ..., write_request: _Optional[_Union[StreamWriteMessage.WriteRequest, _Mapping]] = ..., update_token_request: _Optional[_Union[UpdateTokenRequest, _Mapping]] = ...) -> None: ...
    class FromServer(_message.Message):
        __slots__ = ("status", "issues", "init_response", "write_response", "update_token_response")
        STATUS_FIELD_NUMBER: _ClassVar[int]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        INIT_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        WRITE_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        UPDATE_TOKEN_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        init_response: StreamWriteMessage.InitResponse
        write_response: StreamWriteMessage.WriteResponse
        update_token_response: UpdateTokenResponse
        def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., init_response: _Optional[_Union[StreamWriteMessage.InitResponse, _Mapping]] = ..., write_response: _Optional[_Union[StreamWriteMessage.WriteResponse, _Mapping]] = ..., update_token_response: _Optional[_Union[UpdateTokenResponse, _Mapping]] = ...) -> None: ...
    class InitRequest(_message.Message):
        __slots__ = ("path", "producer_id", "write_session_meta", "message_group_id", "partition_id", "partition_with_generation", "get_last_seq_no")
        class WriteSessionMetaEntry(_message.Message):
            __slots__ = ("key", "value")
            KEY_FIELD_NUMBER: _ClassVar[int]
            VALUE_FIELD_NUMBER: _ClassVar[int]
            key: str
            value: str
            def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
        PATH_FIELD_NUMBER: _ClassVar[int]
        PRODUCER_ID_FIELD_NUMBER: _ClassVar[int]
        WRITE_SESSION_META_FIELD_NUMBER: _ClassVar[int]
        MESSAGE_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_WITH_GENERATION_FIELD_NUMBER: _ClassVar[int]
        GET_LAST_SEQ_NO_FIELD_NUMBER: _ClassVar[int]
        path: str
        producer_id: str
        write_session_meta: _containers.ScalarMap[str, str]
        message_group_id: str
        partition_id: int
        partition_with_generation: PartitionWithGeneration
        get_last_seq_no: bool
        def __init__(self, path: _Optional[str] = ..., producer_id: _Optional[str] = ..., write_session_meta: _Optional[_Mapping[str, str]] = ..., message_group_id: _Optional[str] = ..., partition_id: _Optional[int] = ..., partition_with_generation: _Optional[_Union[PartitionWithGeneration, _Mapping]] = ..., get_last_seq_no: bool = ...) -> None: ...
    class InitResponse(_message.Message):
        __slots__ = ("last_seq_no", "session_id", "partition_id", "supported_codecs")
        LAST_SEQ_NO_FIELD_NUMBER: _ClassVar[int]
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
        SUPPORTED_CODECS_FIELD_NUMBER: _ClassVar[int]
        last_seq_no: int
        session_id: str
        partition_id: int
        supported_codecs: SupportedCodecs
        def __init__(self, last_seq_no: _Optional[int] = ..., session_id: _Optional[str] = ..., partition_id: _Optional[int] = ..., supported_codecs: _Optional[_Union[SupportedCodecs, _Mapping]] = ...) -> None: ...
    class WriteRequest(_message.Message):
        __slots__ = ("messages", "codec", "tx")
        class MessageData(_message.Message):
            __slots__ = ("seq_no", "created_at", "data", "uncompressed_size", "message_group_id", "partition_id", "partition_with_generation", "metadata_items")
            SEQ_NO_FIELD_NUMBER: _ClassVar[int]
            CREATED_AT_FIELD_NUMBER: _ClassVar[int]
            DATA_FIELD_NUMBER: _ClassVar[int]
            UNCOMPRESSED_SIZE_FIELD_NUMBER: _ClassVar[int]
            MESSAGE_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
            PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
            PARTITION_WITH_GENERATION_FIELD_NUMBER: _ClassVar[int]
            METADATA_ITEMS_FIELD_NUMBER: _ClassVar[int]
            seq_no: int
            created_at: _timestamp_pb2.Timestamp
            data: bytes
            uncompressed_size: int
            message_group_id: str
            partition_id: int
            partition_with_generation: PartitionWithGeneration
            metadata_items: _containers.RepeatedCompositeFieldContainer[MetadataItem]
            def __init__(self, seq_no: _Optional[int] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., data: _Optional[bytes] = ..., uncompressed_size: _Optional[int] = ..., message_group_id: _Optional[str] = ..., partition_id: _Optional[int] = ..., partition_with_generation: _Optional[_Union[PartitionWithGeneration, _Mapping]] = ..., metadata_items: _Optional[_Iterable[_Union[MetadataItem, _Mapping]]] = ...) -> None: ...
        MESSAGES_FIELD_NUMBER: _ClassVar[int]
        CODEC_FIELD_NUMBER: _ClassVar[int]
        TX_FIELD_NUMBER: _ClassVar[int]
        messages: _containers.RepeatedCompositeFieldContainer[StreamWriteMessage.WriteRequest.MessageData]
        codec: int
        tx: TransactionIdentity
        def __init__(self, messages: _Optional[_Iterable[_Union[StreamWriteMessage.WriteRequest.MessageData, _Mapping]]] = ..., codec: _Optional[int] = ..., tx: _Optional[_Union[TransactionIdentity, _Mapping]] = ...) -> None: ...
    class WriteResponse(_message.Message):
        __slots__ = ("acks", "partition_id", "write_statistics")
        class WriteAck(_message.Message):
            __slots__ = ("seq_no", "written", "skipped", "written_in_tx")
            class Written(_message.Message):
                __slots__ = ("offset",)
                OFFSET_FIELD_NUMBER: _ClassVar[int]
                offset: int
                def __init__(self, offset: _Optional[int] = ...) -> None: ...
            class Skipped(_message.Message):
                __slots__ = ("reason",)
                class Reason(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
                    __slots__ = ()
                    REASON_UNSPECIFIED: _ClassVar[StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason]
                    REASON_ALREADY_WRITTEN: _ClassVar[StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason]
                REASON_UNSPECIFIED: StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason
                REASON_ALREADY_WRITTEN: StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason
                REASON_FIELD_NUMBER: _ClassVar[int]
                reason: StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason
                def __init__(self, reason: _Optional[_Union[StreamWriteMessage.WriteResponse.WriteAck.Skipped.Reason, str]] = ...) -> None: ...
            class WrittenInTx(_message.Message):
                __slots__ = ()
                def __init__(self) -> None: ...
            SEQ_NO_FIELD_NUMBER: _ClassVar[int]
            WRITTEN_FIELD_NUMBER: _ClassVar[int]
            SKIPPED_FIELD_NUMBER: _ClassVar[int]
            WRITTEN_IN_TX_FIELD_NUMBER: _ClassVar[int]
            seq_no: int
            written: StreamWriteMessage.WriteResponse.WriteAck.Written
            skipped: StreamWriteMessage.WriteResponse.WriteAck.Skipped
            written_in_tx: StreamWriteMessage.WriteResponse.WriteAck.WrittenInTx
            def __init__(self, seq_no: _Optional[int] = ..., written: _Optional[_Union[StreamWriteMessage.WriteResponse.WriteAck.Written, _Mapping]] = ..., skipped: _Optional[_Union[StreamWriteMessage.WriteResponse.WriteAck.Skipped, _Mapping]] = ..., written_in_tx: _Optional[_Union[StreamWriteMessage.WriteResponse.WriteAck.WrittenInTx, _Mapping]] = ...) -> None: ...
        class WriteStatistics(_message.Message):
            __slots__ = ("persisting_time", "min_queue_wait_time", "max_queue_wait_time", "partition_quota_wait_time", "topic_quota_wait_time")
            PERSISTING_TIME_FIELD_NUMBER: _ClassVar[int]
            MIN_QUEUE_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
            MAX_QUEUE_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
            PARTITION_QUOTA_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
            TOPIC_QUOTA_WAIT_TIME_FIELD_NUMBER: _ClassVar[int]
            persisting_time: _duration_pb2.Duration
            min_queue_wait_time: _duration_pb2.Duration
            max_queue_wait_time: _duration_pb2.Duration
            partition_quota_wait_time: _duration_pb2.Duration
            topic_quota_wait_time: _duration_pb2.Duration
            def __init__(self, persisting_time: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., min_queue_wait_time: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_queue_wait_time: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., partition_quota_wait_time: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., topic_quota_wait_time: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...
        ACKS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
        WRITE_STATISTICS_FIELD_NUMBER: _ClassVar[int]
        acks: _containers.RepeatedCompositeFieldContainer[StreamWriteMessage.WriteResponse.WriteAck]
        partition_id: int
        write_statistics: StreamWriteMessage.WriteResponse.WriteStatistics
        def __init__(self, acks: _Optional[_Iterable[_Union[StreamWriteMessage.WriteResponse.WriteAck, _Mapping]]] = ..., partition_id: _Optional[int] = ..., write_statistics: _Optional[_Union[StreamWriteMessage.WriteResponse.WriteStatistics, _Mapping]] = ...) -> None: ...
    def __init__(self) -> None: ...

class StreamReadMessage(_message.Message):
    __slots__ = ()
    class PartitionSession(_message.Message):
        __slots__ = ("partition_session_id", "path", "partition_id")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        PATH_FIELD_NUMBER: _ClassVar[int]
        PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        path: str
        partition_id: int
        def __init__(self, partition_session_id: _Optional[int] = ..., path: _Optional[str] = ..., partition_id: _Optional[int] = ...) -> None: ...
    class FromClient(_message.Message):
        __slots__ = ("init_request", "read_request", "commit_offset_request", "partition_session_status_request", "update_token_request", "direct_read_ack", "start_partition_session_response", "stop_partition_session_response")
        INIT_REQUEST_FIELD_NUMBER: _ClassVar[int]
        READ_REQUEST_FIELD_NUMBER: _ClassVar[int]
        COMMIT_OFFSET_REQUEST_FIELD_NUMBER: _ClassVar[int]
        PARTITION_SESSION_STATUS_REQUEST_FIELD_NUMBER: _ClassVar[int]
        UPDATE_TOKEN_REQUEST_FIELD_NUMBER: _ClassVar[int]
        DIRECT_READ_ACK_FIELD_NUMBER: _ClassVar[int]
        START_PARTITION_SESSION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        STOP_PARTITION_SESSION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        init_request: StreamReadMessage.InitRequest
        read_request: StreamReadMessage.ReadRequest
        commit_offset_request: StreamReadMessage.CommitOffsetRequest
        partition_session_status_request: StreamReadMessage.PartitionSessionStatusRequest
        update_token_request: UpdateTokenRequest
        direct_read_ack: StreamReadMessage.DirectReadAck
        start_partition_session_response: StreamReadMessage.StartPartitionSessionResponse
        stop_partition_session_response: StreamReadMessage.StopPartitionSessionResponse
        def __init__(self, init_request: _Optional[_Union[StreamReadMessage.InitRequest, _Mapping]] = ..., read_request: _Optional[_Union[StreamReadMessage.ReadRequest, _Mapping]] = ..., commit_offset_request: _Optional[_Union[StreamReadMessage.CommitOffsetRequest, _Mapping]] = ..., partition_session_status_request: _Optional[_Union[StreamReadMessage.PartitionSessionStatusRequest, _Mapping]] = ..., update_token_request: _Optional[_Union[UpdateTokenRequest, _Mapping]] = ..., direct_read_ack: _Optional[_Union[StreamReadMessage.DirectReadAck, _Mapping]] = ..., start_partition_session_response: _Optional[_Union[StreamReadMessage.StartPartitionSessionResponse, _Mapping]] = ..., stop_partition_session_response: _Optional[_Union[StreamReadMessage.StopPartitionSessionResponse, _Mapping]] = ...) -> None: ...
    class FromServer(_message.Message):
        __slots__ = ("status", "issues", "init_response", "read_response", "commit_offset_response", "partition_session_status_response", "update_token_response", "start_partition_session_request", "stop_partition_session_request", "update_partition_session", "end_partition_session")
        STATUS_FIELD_NUMBER: _ClassVar[int]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        INIT_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        READ_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        COMMIT_OFFSET_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        PARTITION_SESSION_STATUS_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        UPDATE_TOKEN_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        START_PARTITION_SESSION_REQUEST_FIELD_NUMBER: _ClassVar[int]
        STOP_PARTITION_SESSION_REQUEST_FIELD_NUMBER: _ClassVar[int]
        UPDATE_PARTITION_SESSION_FIELD_NUMBER: _ClassVar[int]
        END_PARTITION_SESSION_FIELD_NUMBER: _ClassVar[int]
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        init_response: StreamReadMessage.InitResponse
        read_response: StreamReadMessage.ReadResponse
        commit_offset_response: StreamReadMessage.CommitOffsetResponse
        partition_session_status_response: StreamReadMessage.PartitionSessionStatusResponse
        update_token_response: UpdateTokenResponse
        start_partition_session_request: StreamReadMessage.StartPartitionSessionRequest
        stop_partition_session_request: StreamReadMessage.StopPartitionSessionRequest
        update_partition_session: StreamReadMessage.UpdatePartitionSession
        end_partition_session: StreamReadMessage.EndPartitionSession
        def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., init_response: _Optional[_Union[StreamReadMessage.InitResponse, _Mapping]] = ..., read_response: _Optional[_Union[StreamReadMessage.ReadResponse, _Mapping]] = ..., commit_offset_response: _Optional[_Union[StreamReadMessage.CommitOffsetResponse, _Mapping]] = ..., partition_session_status_response: _Optional[_Union[StreamReadMessage.PartitionSessionStatusResponse, _Mapping]] = ..., update_token_response: _Optional[_Union[UpdateTokenResponse, _Mapping]] = ..., start_partition_session_request: _Optional[_Union[StreamReadMessage.StartPartitionSessionRequest, _Mapping]] = ..., stop_partition_session_request: _Optional[_Union[StreamReadMessage.StopPartitionSessionRequest, _Mapping]] = ..., update_partition_session: _Optional[_Union[StreamReadMessage.UpdatePartitionSession, _Mapping]] = ..., end_partition_session: _Optional[_Union[StreamReadMessage.EndPartitionSession, _Mapping]] = ...) -> None: ...
    class InitRequest(_message.Message):
        __slots__ = ("topics_read_settings", "consumer", "reader_name", "direct_read", "auto_partitioning_support")
        class TopicReadSettings(_message.Message):
            __slots__ = ("path", "partition_ids", "max_lag", "read_from")
            PATH_FIELD_NUMBER: _ClassVar[int]
            PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
            MAX_LAG_FIELD_NUMBER: _ClassVar[int]
            READ_FROM_FIELD_NUMBER: _ClassVar[int]
            path: str
            partition_ids: _containers.RepeatedScalarFieldContainer[int]
            max_lag: _duration_pb2.Duration
            read_from: _timestamp_pb2.Timestamp
            def __init__(self, path: _Optional[str] = ..., partition_ids: _Optional[_Iterable[int]] = ..., max_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., read_from: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        TOPICS_READ_SETTINGS_FIELD_NUMBER: _ClassVar[int]
        CONSUMER_FIELD_NUMBER: _ClassVar[int]
        READER_NAME_FIELD_NUMBER: _ClassVar[int]
        DIRECT_READ_FIELD_NUMBER: _ClassVar[int]
        AUTO_PARTITIONING_SUPPORT_FIELD_NUMBER: _ClassVar[int]
        topics_read_settings: _containers.RepeatedCompositeFieldContainer[StreamReadMessage.InitRequest.TopicReadSettings]
        consumer: str
        reader_name: str
        direct_read: bool
        auto_partitioning_support: bool
        def __init__(self, topics_read_settings: _Optional[_Iterable[_Union[StreamReadMessage.InitRequest.TopicReadSettings, _Mapping]]] = ..., consumer: _Optional[str] = ..., reader_name: _Optional[str] = ..., direct_read: bool = ..., auto_partitioning_support: bool = ...) -> None: ...
    class InitResponse(_message.Message):
        __slots__ = ("session_id",)
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        session_id: str
        def __init__(self, session_id: _Optional[str] = ...) -> None: ...
    class ReadRequest(_message.Message):
        __slots__ = ("bytes_size",)
        BYTES_SIZE_FIELD_NUMBER: _ClassVar[int]
        bytes_size: int
        def __init__(self, bytes_size: _Optional[int] = ...) -> None: ...
    class ReadResponse(_message.Message):
        __slots__ = ("partition_data", "bytes_size")
        class MessageData(_message.Message):
            __slots__ = ("offset", "seq_no", "created_at", "data", "uncompressed_size", "message_group_id", "metadata_items")
            OFFSET_FIELD_NUMBER: _ClassVar[int]
            SEQ_NO_FIELD_NUMBER: _ClassVar[int]
            CREATED_AT_FIELD_NUMBER: _ClassVar[int]
            DATA_FIELD_NUMBER: _ClassVar[int]
            UNCOMPRESSED_SIZE_FIELD_NUMBER: _ClassVar[int]
            MESSAGE_GROUP_ID_FIELD_NUMBER: _ClassVar[int]
            METADATA_ITEMS_FIELD_NUMBER: _ClassVar[int]
            offset: int
            seq_no: int
            created_at: _timestamp_pb2.Timestamp
            data: bytes
            uncompressed_size: int
            message_group_id: str
            metadata_items: _containers.RepeatedCompositeFieldContainer[MetadataItem]
            def __init__(self, offset: _Optional[int] = ..., seq_no: _Optional[int] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., data: _Optional[bytes] = ..., uncompressed_size: _Optional[int] = ..., message_group_id: _Optional[str] = ..., metadata_items: _Optional[_Iterable[_Union[MetadataItem, _Mapping]]] = ...) -> None: ...
        class Batch(_message.Message):
            __slots__ = ("message_data", "producer_id", "write_session_meta", "codec", "written_at")
            class WriteSessionMetaEntry(_message.Message):
                __slots__ = ("key", "value")
                KEY_FIELD_NUMBER: _ClassVar[int]
                VALUE_FIELD_NUMBER: _ClassVar[int]
                key: str
                value: str
                def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
            MESSAGE_DATA_FIELD_NUMBER: _ClassVar[int]
            PRODUCER_ID_FIELD_NUMBER: _ClassVar[int]
            WRITE_SESSION_META_FIELD_NUMBER: _ClassVar[int]
            CODEC_FIELD_NUMBER: _ClassVar[int]
            WRITTEN_AT_FIELD_NUMBER: _ClassVar[int]
            message_data: _containers.RepeatedCompositeFieldContainer[StreamReadMessage.ReadResponse.MessageData]
            producer_id: str
            write_session_meta: _containers.ScalarMap[str, str]
            codec: int
            written_at: _timestamp_pb2.Timestamp
            def __init__(self, message_data: _Optional[_Iterable[_Union[StreamReadMessage.ReadResponse.MessageData, _Mapping]]] = ..., producer_id: _Optional[str] = ..., write_session_meta: _Optional[_Mapping[str, str]] = ..., codec: _Optional[int] = ..., written_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
        class PartitionData(_message.Message):
            __slots__ = ("partition_session_id", "batches")
            PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
            BATCHES_FIELD_NUMBER: _ClassVar[int]
            partition_session_id: int
            batches: _containers.RepeatedCompositeFieldContainer[StreamReadMessage.ReadResponse.Batch]
            def __init__(self, partition_session_id: _Optional[int] = ..., batches: _Optional[_Iterable[_Union[StreamReadMessage.ReadResponse.Batch, _Mapping]]] = ...) -> None: ...
        PARTITION_DATA_FIELD_NUMBER: _ClassVar[int]
        BYTES_SIZE_FIELD_NUMBER: _ClassVar[int]
        partition_data: _containers.RepeatedCompositeFieldContainer[StreamReadMessage.ReadResponse.PartitionData]
        bytes_size: int
        def __init__(self, partition_data: _Optional[_Iterable[_Union[StreamReadMessage.ReadResponse.PartitionData, _Mapping]]] = ..., bytes_size: _Optional[int] = ...) -> None: ...
    class CommitOffsetRequest(_message.Message):
        __slots__ = ("commit_offsets",)
        class PartitionCommitOffset(_message.Message):
            __slots__ = ("partition_session_id", "offsets")
            PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
            OFFSETS_FIELD_NUMBER: _ClassVar[int]
            partition_session_id: int
            offsets: _containers.RepeatedCompositeFieldContainer[OffsetsRange]
            def __init__(self, partition_session_id: _Optional[int] = ..., offsets: _Optional[_Iterable[_Union[OffsetsRange, _Mapping]]] = ...) -> None: ...
        COMMIT_OFFSETS_FIELD_NUMBER: _ClassVar[int]
        commit_offsets: _containers.RepeatedCompositeFieldContainer[StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset]
        def __init__(self, commit_offsets: _Optional[_Iterable[_Union[StreamReadMessage.CommitOffsetRequest.PartitionCommitOffset, _Mapping]]] = ...) -> None: ...
    class CommitOffsetResponse(_message.Message):
        __slots__ = ("partitions_committed_offsets",)
        class PartitionCommittedOffset(_message.Message):
            __slots__ = ("partition_session_id", "committed_offset")
            PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
            COMMITTED_OFFSET_FIELD_NUMBER: _ClassVar[int]
            partition_session_id: int
            committed_offset: int
            def __init__(self, partition_session_id: _Optional[int] = ..., committed_offset: _Optional[int] = ...) -> None: ...
        PARTITIONS_COMMITTED_OFFSETS_FIELD_NUMBER: _ClassVar[int]
        partitions_committed_offsets: _containers.RepeatedCompositeFieldContainer[StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset]
        def __init__(self, partitions_committed_offsets: _Optional[_Iterable[_Union[StreamReadMessage.CommitOffsetResponse.PartitionCommittedOffset, _Mapping]]] = ...) -> None: ...
    class PartitionSessionStatusRequest(_message.Message):
        __slots__ = ("partition_session_id",)
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        def __init__(self, partition_session_id: _Optional[int] = ...) -> None: ...
    class PartitionSessionStatusResponse(_message.Message):
        __slots__ = ("partition_session_id", "partition_offsets", "committed_offset", "write_time_high_watermark")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_OFFSETS_FIELD_NUMBER: _ClassVar[int]
        COMMITTED_OFFSET_FIELD_NUMBER: _ClassVar[int]
        WRITE_TIME_HIGH_WATERMARK_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        partition_offsets: OffsetsRange
        committed_offset: int
        write_time_high_watermark: _timestamp_pb2.Timestamp
        def __init__(self, partition_session_id: _Optional[int] = ..., partition_offsets: _Optional[_Union[OffsetsRange, _Mapping]] = ..., committed_offset: _Optional[int] = ..., write_time_high_watermark: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...
    class StartPartitionSessionRequest(_message.Message):
        __slots__ = ("partition_session", "committed_offset", "partition_offsets", "partition_location")
        PARTITION_SESSION_FIELD_NUMBER: _ClassVar[int]
        COMMITTED_OFFSET_FIELD_NUMBER: _ClassVar[int]
        PARTITION_OFFSETS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_LOCATION_FIELD_NUMBER: _ClassVar[int]
        partition_session: StreamReadMessage.PartitionSession
        committed_offset: int
        partition_offsets: OffsetsRange
        partition_location: PartitionLocation
        def __init__(self, partition_session: _Optional[_Union[StreamReadMessage.PartitionSession, _Mapping]] = ..., committed_offset: _Optional[int] = ..., partition_offsets: _Optional[_Union[OffsetsRange, _Mapping]] = ..., partition_location: _Optional[_Union[PartitionLocation, _Mapping]] = ...) -> None: ...
    class StartPartitionSessionResponse(_message.Message):
        __slots__ = ("partition_session_id", "read_offset", "commit_offset")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        READ_OFFSET_FIELD_NUMBER: _ClassVar[int]
        COMMIT_OFFSET_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        read_offset: int
        commit_offset: int
        def __init__(self, partition_session_id: _Optional[int] = ..., read_offset: _Optional[int] = ..., commit_offset: _Optional[int] = ...) -> None: ...
    class StopPartitionSessionRequest(_message.Message):
        __slots__ = ("partition_session_id", "graceful", "committed_offset", "last_direct_read_id")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        GRACEFUL_FIELD_NUMBER: _ClassVar[int]
        COMMITTED_OFFSET_FIELD_NUMBER: _ClassVar[int]
        LAST_DIRECT_READ_ID_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        graceful: bool
        committed_offset: int
        last_direct_read_id: int
        def __init__(self, partition_session_id: _Optional[int] = ..., graceful: bool = ..., committed_offset: _Optional[int] = ..., last_direct_read_id: _Optional[int] = ...) -> None: ...
    class StopPartitionSessionResponse(_message.Message):
        __slots__ = ("partition_session_id", "graceful")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        GRACEFUL_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        graceful: bool
        def __init__(self, partition_session_id: _Optional[int] = ..., graceful: bool = ...) -> None: ...
    class UpdatePartitionSession(_message.Message):
        __slots__ = ("partition_session_id", "partition_location")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_LOCATION_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        partition_location: PartitionLocation
        def __init__(self, partition_session_id: _Optional[int] = ..., partition_location: _Optional[_Union[PartitionLocation, _Mapping]] = ...) -> None: ...
    class DirectReadAck(_message.Message):
        __slots__ = ("partition_session_id", "direct_read_id")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        DIRECT_READ_ID_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        direct_read_id: int
        def __init__(self, partition_session_id: _Optional[int] = ..., direct_read_id: _Optional[int] = ...) -> None: ...
    class EndPartitionSession(_message.Message):
        __slots__ = ("partition_session_id", "adjacent_partition_ids", "child_partition_ids")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        ADJACENT_PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
        CHILD_PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        adjacent_partition_ids: _containers.RepeatedScalarFieldContainer[int]
        child_partition_ids: _containers.RepeatedScalarFieldContainer[int]
        def __init__(self, partition_session_id: _Optional[int] = ..., adjacent_partition_ids: _Optional[_Iterable[int]] = ..., child_partition_ids: _Optional[_Iterable[int]] = ...) -> None: ...
    def __init__(self) -> None: ...

class StreamDirectReadMessage(_message.Message):
    __slots__ = ()
    class FromClient(_message.Message):
        __slots__ = ("init_request", "start_direct_read_partition_session_request", "update_token_request")
        INIT_REQUEST_FIELD_NUMBER: _ClassVar[int]
        START_DIRECT_READ_PARTITION_SESSION_REQUEST_FIELD_NUMBER: _ClassVar[int]
        UPDATE_TOKEN_REQUEST_FIELD_NUMBER: _ClassVar[int]
        init_request: StreamDirectReadMessage.InitRequest
        start_direct_read_partition_session_request: StreamDirectReadMessage.StartDirectReadPartitionSessionRequest
        update_token_request: UpdateTokenRequest
        def __init__(self, init_request: _Optional[_Union[StreamDirectReadMessage.InitRequest, _Mapping]] = ..., start_direct_read_partition_session_request: _Optional[_Union[StreamDirectReadMessage.StartDirectReadPartitionSessionRequest, _Mapping]] = ..., update_token_request: _Optional[_Union[UpdateTokenRequest, _Mapping]] = ...) -> None: ...
    class FromServer(_message.Message):
        __slots__ = ("status", "issues", "init_response", "start_direct_read_partition_session_response", "stop_direct_read_partition_session", "direct_read_response", "update_token_response")
        STATUS_FIELD_NUMBER: _ClassVar[int]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        INIT_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        START_DIRECT_READ_PARTITION_SESSION_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        STOP_DIRECT_READ_PARTITION_SESSION_FIELD_NUMBER: _ClassVar[int]
        DIRECT_READ_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        UPDATE_TOKEN_RESPONSE_FIELD_NUMBER: _ClassVar[int]
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        init_response: StreamDirectReadMessage.InitResponse
        start_direct_read_partition_session_response: StreamDirectReadMessage.StartDirectReadPartitionSessionResponse
        stop_direct_read_partition_session: StreamDirectReadMessage.StopDirectReadPartitionSession
        direct_read_response: StreamDirectReadMessage.DirectReadResponse
        update_token_response: UpdateTokenResponse
        def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., init_response: _Optional[_Union[StreamDirectReadMessage.InitResponse, _Mapping]] = ..., start_direct_read_partition_session_response: _Optional[_Union[StreamDirectReadMessage.StartDirectReadPartitionSessionResponse, _Mapping]] = ..., stop_direct_read_partition_session: _Optional[_Union[StreamDirectReadMessage.StopDirectReadPartitionSession, _Mapping]] = ..., direct_read_response: _Optional[_Union[StreamDirectReadMessage.DirectReadResponse, _Mapping]] = ..., update_token_response: _Optional[_Union[UpdateTokenResponse, _Mapping]] = ...) -> None: ...
    class InitRequest(_message.Message):
        __slots__ = ("session_id", "topics_read_settings", "consumer")
        class TopicReadSettings(_message.Message):
            __slots__ = ("path",)
            PATH_FIELD_NUMBER: _ClassVar[int]
            path: str
            def __init__(self, path: _Optional[str] = ...) -> None: ...
        SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        TOPICS_READ_SETTINGS_FIELD_NUMBER: _ClassVar[int]
        CONSUMER_FIELD_NUMBER: _ClassVar[int]
        session_id: str
        topics_read_settings: _containers.RepeatedCompositeFieldContainer[StreamDirectReadMessage.InitRequest.TopicReadSettings]
        consumer: str
        def __init__(self, session_id: _Optional[str] = ..., topics_read_settings: _Optional[_Iterable[_Union[StreamDirectReadMessage.InitRequest.TopicReadSettings, _Mapping]]] = ..., consumer: _Optional[str] = ...) -> None: ...
    class InitResponse(_message.Message):
        __slots__ = ()
        def __init__(self) -> None: ...
    class StartDirectReadPartitionSessionRequest(_message.Message):
        __slots__ = ("partition_session_id", "last_direct_read_id", "generation")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        LAST_DIRECT_READ_ID_FIELD_NUMBER: _ClassVar[int]
        GENERATION_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        last_direct_read_id: int
        generation: int
        def __init__(self, partition_session_id: _Optional[int] = ..., last_direct_read_id: _Optional[int] = ..., generation: _Optional[int] = ...) -> None: ...
    class StartDirectReadPartitionSessionResponse(_message.Message):
        __slots__ = ("partition_session_id", "generation")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        GENERATION_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        generation: int
        def __init__(self, partition_session_id: _Optional[int] = ..., generation: _Optional[int] = ...) -> None: ...
    class StopDirectReadPartitionSession(_message.Message):
        __slots__ = ("status", "issues", "partition_session_id", "generation")
        STATUS_FIELD_NUMBER: _ClassVar[int]
        ISSUES_FIELD_NUMBER: _ClassVar[int]
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        GENERATION_FIELD_NUMBER: _ClassVar[int]
        status: _ydb_status_codes_pb2.StatusIds.StatusCode
        issues: _containers.RepeatedCompositeFieldContainer[_ydb_issue_message_pb2.IssueMessage]
        partition_session_id: int
        generation: int
        def __init__(self, status: _Optional[_Union[_ydb_status_codes_pb2.StatusIds.StatusCode, str]] = ..., issues: _Optional[_Iterable[_Union[_ydb_issue_message_pb2.IssueMessage, _Mapping]]] = ..., partition_session_id: _Optional[int] = ..., generation: _Optional[int] = ...) -> None: ...
    class DirectReadResponse(_message.Message):
        __slots__ = ("partition_session_id", "direct_read_id", "partition_data", "bytes_size")
        PARTITION_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        DIRECT_READ_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_DATA_FIELD_NUMBER: _ClassVar[int]
        BYTES_SIZE_FIELD_NUMBER: _ClassVar[int]
        partition_session_id: int
        direct_read_id: int
        partition_data: StreamReadMessage.ReadResponse.PartitionData
        bytes_size: int
        def __init__(self, partition_session_id: _Optional[int] = ..., direct_read_id: _Optional[int] = ..., partition_data: _Optional[_Union[StreamReadMessage.ReadResponse.PartitionData, _Mapping]] = ..., bytes_size: _Optional[int] = ...) -> None: ...
    def __init__(self) -> None: ...

class TransactionIdentity(_message.Message):
    __slots__ = ("id", "session")
    ID_FIELD_NUMBER: _ClassVar[int]
    SESSION_FIELD_NUMBER: _ClassVar[int]
    id: str
    session: str
    def __init__(self, id: _Optional[str] = ..., session: _Optional[str] = ...) -> None: ...

class UpdateOffsetsInTransactionRequest(_message.Message):
    __slots__ = ("operation_params", "tx", "topics", "consumer")
    class TopicOffsets(_message.Message):
        __slots__ = ("path", "partitions")
        class PartitionOffsets(_message.Message):
            __slots__ = ("partition_id", "partition_offsets")
            PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
            PARTITION_OFFSETS_FIELD_NUMBER: _ClassVar[int]
            partition_id: int
            partition_offsets: _containers.RepeatedCompositeFieldContainer[OffsetsRange]
            def __init__(self, partition_id: _Optional[int] = ..., partition_offsets: _Optional[_Iterable[_Union[OffsetsRange, _Mapping]]] = ...) -> None: ...
        PATH_FIELD_NUMBER: _ClassVar[int]
        PARTITIONS_FIELD_NUMBER: _ClassVar[int]
        path: str
        partitions: _containers.RepeatedCompositeFieldContainer[UpdateOffsetsInTransactionRequest.TopicOffsets.PartitionOffsets]
        def __init__(self, path: _Optional[str] = ..., partitions: _Optional[_Iterable[_Union[UpdateOffsetsInTransactionRequest.TopicOffsets.PartitionOffsets, _Mapping]]] = ...) -> None: ...
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    TX_FIELD_NUMBER: _ClassVar[int]
    TOPICS_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    tx: TransactionIdentity
    topics: _containers.RepeatedCompositeFieldContainer[UpdateOffsetsInTransactionRequest.TopicOffsets]
    consumer: str
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., tx: _Optional[_Union[TransactionIdentity, _Mapping]] = ..., topics: _Optional[_Iterable[_Union[UpdateOffsetsInTransactionRequest.TopicOffsets, _Mapping]]] = ..., consumer: _Optional[str] = ...) -> None: ...

class UpdateOffsetsInTransactionResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class UpdateOffsetsInTransactionResult(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class CommitOffsetRequest(_message.Message):
    __slots__ = ("operation_params", "path", "partition_id", "consumer", "offset", "read_session_id")
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_FIELD_NUMBER: _ClassVar[int]
    OFFSET_FIELD_NUMBER: _ClassVar[int]
    READ_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    partition_id: int
    consumer: str
    offset: int
    read_session_id: str
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ..., partition_id: _Optional[int] = ..., consumer: _Optional[str] = ..., offset: _Optional[int] = ..., read_session_id: _Optional[str] = ...) -> None: ...

class CommitOffsetResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class CommitOffsetResult(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class MultipleWindowsStat(_message.Message):
    __slots__ = ("per_minute", "per_hour", "per_day")
    PER_MINUTE_FIELD_NUMBER: _ClassVar[int]
    PER_HOUR_FIELD_NUMBER: _ClassVar[int]
    PER_DAY_FIELD_NUMBER: _ClassVar[int]
    per_minute: int
    per_hour: int
    per_day: int
    def __init__(self, per_minute: _Optional[int] = ..., per_hour: _Optional[int] = ..., per_day: _Optional[int] = ...) -> None: ...

class Consumer(_message.Message):
    __slots__ = ("name", "important", "read_from", "supported_codecs", "attributes", "consumer_stats", "availability_period")
    class AttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class ConsumerStats(_message.Message):
        __slots__ = ("min_partitions_last_read_time", "max_read_time_lag", "max_write_time_lag", "max_committed_time_lag", "bytes_read")
        MIN_PARTITIONS_LAST_READ_TIME_FIELD_NUMBER: _ClassVar[int]
        MAX_READ_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        MAX_WRITE_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        MAX_COMMITTED_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        BYTES_READ_FIELD_NUMBER: _ClassVar[int]
        min_partitions_last_read_time: _timestamp_pb2.Timestamp
        max_read_time_lag: _duration_pb2.Duration
        max_write_time_lag: _duration_pb2.Duration
        max_committed_time_lag: _duration_pb2.Duration
        bytes_read: MultipleWindowsStat
        def __init__(self, min_partitions_last_read_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., max_read_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_write_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_committed_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., bytes_read: _Optional[_Union[MultipleWindowsStat, _Mapping]] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMPORTANT_FIELD_NUMBER: _ClassVar[int]
    READ_FROM_FIELD_NUMBER: _ClassVar[int]
    SUPPORTED_CODECS_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_STATS_FIELD_NUMBER: _ClassVar[int]
    AVAILABILITY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    name: str
    important: bool
    read_from: _timestamp_pb2.Timestamp
    supported_codecs: SupportedCodecs
    attributes: _containers.ScalarMap[str, str]
    consumer_stats: Consumer.ConsumerStats
    availability_period: _duration_pb2.Duration
    def __init__(self, name: _Optional[str] = ..., important: bool = ..., read_from: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., supported_codecs: _Optional[_Union[SupportedCodecs, _Mapping]] = ..., attributes: _Optional[_Mapping[str, str]] = ..., consumer_stats: _Optional[_Union[Consumer.ConsumerStats, _Mapping]] = ..., availability_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ...) -> None: ...

class AlterConsumer(_message.Message):
    __slots__ = ("name", "set_important", "set_read_from", "set_supported_codecs", "alter_attributes", "set_availability_period", "reset_availability_period")
    class AlterAttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    NAME_FIELD_NUMBER: _ClassVar[int]
    SET_IMPORTANT_FIELD_NUMBER: _ClassVar[int]
    SET_READ_FROM_FIELD_NUMBER: _ClassVar[int]
    SET_SUPPORTED_CODECS_FIELD_NUMBER: _ClassVar[int]
    ALTER_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    SET_AVAILABILITY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    RESET_AVAILABILITY_PERIOD_FIELD_NUMBER: _ClassVar[int]
    name: str
    set_important: bool
    set_read_from: _timestamp_pb2.Timestamp
    set_supported_codecs: SupportedCodecs
    alter_attributes: _containers.ScalarMap[str, str]
    set_availability_period: _duration_pb2.Duration
    reset_availability_period: _empty_pb2.Empty
    def __init__(self, name: _Optional[str] = ..., set_important: bool = ..., set_read_from: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., set_supported_codecs: _Optional[_Union[SupportedCodecs, _Mapping]] = ..., alter_attributes: _Optional[_Mapping[str, str]] = ..., set_availability_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., reset_availability_period: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class PartitioningSettings(_message.Message):
    __slots__ = ("min_active_partitions", "max_active_partitions", "partition_count_limit", "auto_partitioning_settings")
    MIN_ACTIVE_PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    MAX_ACTIVE_PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    PARTITION_COUNT_LIMIT_FIELD_NUMBER: _ClassVar[int]
    AUTO_PARTITIONING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    min_active_partitions: int
    max_active_partitions: int
    partition_count_limit: int
    auto_partitioning_settings: AutoPartitioningSettings
    def __init__(self, min_active_partitions: _Optional[int] = ..., max_active_partitions: _Optional[int] = ..., partition_count_limit: _Optional[int] = ..., auto_partitioning_settings: _Optional[_Union[AutoPartitioningSettings, _Mapping]] = ...) -> None: ...

class AutoPartitioningSettings(_message.Message):
    __slots__ = ("strategy", "partition_write_speed")
    STRATEGY_FIELD_NUMBER: _ClassVar[int]
    PARTITION_WRITE_SPEED_FIELD_NUMBER: _ClassVar[int]
    strategy: AutoPartitioningStrategy
    partition_write_speed: AutoPartitioningWriteSpeedStrategy
    def __init__(self, strategy: _Optional[_Union[AutoPartitioningStrategy, str]] = ..., partition_write_speed: _Optional[_Union[AutoPartitioningWriteSpeedStrategy, _Mapping]] = ...) -> None: ...

class AutoPartitioningWriteSpeedStrategy(_message.Message):
    __slots__ = ("stabilization_window", "up_utilization_percent", "down_utilization_percent")
    STABILIZATION_WINDOW_FIELD_NUMBER: _ClassVar[int]
    UP_UTILIZATION_PERCENT_FIELD_NUMBER: _ClassVar[int]
    DOWN_UTILIZATION_PERCENT_FIELD_NUMBER: _ClassVar[int]
    stabilization_window: _duration_pb2.Duration
    up_utilization_percent: int
    down_utilization_percent: int
    def __init__(self, stabilization_window: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., up_utilization_percent: _Optional[int] = ..., down_utilization_percent: _Optional[int] = ...) -> None: ...

class AlterPartitioningSettings(_message.Message):
    __slots__ = ("set_min_active_partitions", "set_max_active_partitions", "set_partition_count_limit", "alter_auto_partitioning_settings")
    SET_MIN_ACTIVE_PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    SET_MAX_ACTIVE_PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    SET_PARTITION_COUNT_LIMIT_FIELD_NUMBER: _ClassVar[int]
    ALTER_AUTO_PARTITIONING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    set_min_active_partitions: int
    set_max_active_partitions: int
    set_partition_count_limit: int
    alter_auto_partitioning_settings: AlterAutoPartitioningSettings
    def __init__(self, set_min_active_partitions: _Optional[int] = ..., set_max_active_partitions: _Optional[int] = ..., set_partition_count_limit: _Optional[int] = ..., alter_auto_partitioning_settings: _Optional[_Union[AlterAutoPartitioningSettings, _Mapping]] = ...) -> None: ...

class AlterAutoPartitioningSettings(_message.Message):
    __slots__ = ("set_strategy", "set_partition_write_speed")
    SET_STRATEGY_FIELD_NUMBER: _ClassVar[int]
    SET_PARTITION_WRITE_SPEED_FIELD_NUMBER: _ClassVar[int]
    set_strategy: AutoPartitioningStrategy
    set_partition_write_speed: AlterAutoPartitioningWriteSpeedStrategy
    def __init__(self, set_strategy: _Optional[_Union[AutoPartitioningStrategy, str]] = ..., set_partition_write_speed: _Optional[_Union[AlterAutoPartitioningWriteSpeedStrategy, _Mapping]] = ...) -> None: ...

class AlterAutoPartitioningWriteSpeedStrategy(_message.Message):
    __slots__ = ("set_stabilization_window", "set_up_utilization_percent", "set_down_utilization_percent")
    SET_STABILIZATION_WINDOW_FIELD_NUMBER: _ClassVar[int]
    SET_UP_UTILIZATION_PERCENT_FIELD_NUMBER: _ClassVar[int]
    SET_DOWN_UTILIZATION_PERCENT_FIELD_NUMBER: _ClassVar[int]
    set_stabilization_window: _duration_pb2.Duration
    set_up_utilization_percent: int
    set_down_utilization_percent: int
    def __init__(self, set_stabilization_window: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., set_up_utilization_percent: _Optional[int] = ..., set_down_utilization_percent: _Optional[int] = ...) -> None: ...

class CreateTopicRequest(_message.Message):
    __slots__ = ("operation_params", "path", "partitioning_settings", "retention_period", "retention_storage_mb", "supported_codecs", "partition_write_speed_bytes_per_second", "partition_write_burst_bytes", "attributes", "consumers", "metering_mode")
    class AttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PARTITIONING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    RETENTION_PERIOD_FIELD_NUMBER: _ClassVar[int]
    RETENTION_STORAGE_MB_FIELD_NUMBER: _ClassVar[int]
    SUPPORTED_CODECS_FIELD_NUMBER: _ClassVar[int]
    PARTITION_WRITE_SPEED_BYTES_PER_SECOND_FIELD_NUMBER: _ClassVar[int]
    PARTITION_WRITE_BURST_BYTES_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    METERING_MODE_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    partitioning_settings: PartitioningSettings
    retention_period: _duration_pb2.Duration
    retention_storage_mb: int
    supported_codecs: SupportedCodecs
    partition_write_speed_bytes_per_second: int
    partition_write_burst_bytes: int
    attributes: _containers.ScalarMap[str, str]
    consumers: _containers.RepeatedCompositeFieldContainer[Consumer]
    metering_mode: MeteringMode
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ..., partitioning_settings: _Optional[_Union[PartitioningSettings, _Mapping]] = ..., retention_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., retention_storage_mb: _Optional[int] = ..., supported_codecs: _Optional[_Union[SupportedCodecs, _Mapping]] = ..., partition_write_speed_bytes_per_second: _Optional[int] = ..., partition_write_burst_bytes: _Optional[int] = ..., attributes: _Optional[_Mapping[str, str]] = ..., consumers: _Optional[_Iterable[_Union[Consumer, _Mapping]]] = ..., metering_mode: _Optional[_Union[MeteringMode, str]] = ...) -> None: ...

class CreateTopicResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class CreateTopicResult(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PartitionLocation(_message.Message):
    __slots__ = ("node_id", "generation")
    NODE_ID_FIELD_NUMBER: _ClassVar[int]
    GENERATION_FIELD_NUMBER: _ClassVar[int]
    node_id: int
    generation: int
    def __init__(self, node_id: _Optional[int] = ..., generation: _Optional[int] = ...) -> None: ...

class DescribeTopicRequest(_message.Message):
    __slots__ = ("operation_params", "path", "include_stats", "include_location")
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_STATS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    include_stats: bool
    include_location: bool
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ..., include_stats: bool = ..., include_location: bool = ...) -> None: ...

class DescribeTopicResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class PartitionKeyRange(_message.Message):
    __slots__ = ("from_bound", "to_bound")
    FROM_BOUND_FIELD_NUMBER: _ClassVar[int]
    TO_BOUND_FIELD_NUMBER: _ClassVar[int]
    from_bound: bytes
    to_bound: bytes
    def __init__(self, from_bound: _Optional[bytes] = ..., to_bound: _Optional[bytes] = ...) -> None: ...

class DescribeTopicResult(_message.Message):
    __slots__ = ("self", "partitioning_settings", "partitions", "retention_period", "retention_storage_mb", "supported_codecs", "partition_write_speed_bytes_per_second", "partition_total_read_speed_bytes_per_second", "partition_consumer_read_speed_bytes_per_second", "partition_write_burst_bytes", "attributes", "consumers", "metering_mode", "topic_stats")
    class AttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class PartitionInfo(_message.Message):
        __slots__ = ("partition_id", "active", "child_partition_ids", "parent_partition_ids", "partition_stats", "partition_location", "key_range")
        PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        CHILD_PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
        PARENT_PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_STATS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_LOCATION_FIELD_NUMBER: _ClassVar[int]
        KEY_RANGE_FIELD_NUMBER: _ClassVar[int]
        partition_id: int
        active: bool
        child_partition_ids: _containers.RepeatedScalarFieldContainer[int]
        parent_partition_ids: _containers.RepeatedScalarFieldContainer[int]
        partition_stats: PartitionStats
        partition_location: PartitionLocation
        key_range: PartitionKeyRange
        def __init__(self, partition_id: _Optional[int] = ..., active: bool = ..., child_partition_ids: _Optional[_Iterable[int]] = ..., parent_partition_ids: _Optional[_Iterable[int]] = ..., partition_stats: _Optional[_Union[PartitionStats, _Mapping]] = ..., partition_location: _Optional[_Union[PartitionLocation, _Mapping]] = ..., key_range: _Optional[_Union[PartitionKeyRange, _Mapping]] = ...) -> None: ...
    class TopicStats(_message.Message):
        __slots__ = ("store_size_bytes", "min_last_write_time", "max_write_time_lag", "bytes_written")
        STORE_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
        MIN_LAST_WRITE_TIME_FIELD_NUMBER: _ClassVar[int]
        MAX_WRITE_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        BYTES_WRITTEN_FIELD_NUMBER: _ClassVar[int]
        store_size_bytes: int
        min_last_write_time: _timestamp_pb2.Timestamp
        max_write_time_lag: _duration_pb2.Duration
        bytes_written: MultipleWindowsStat
        def __init__(self, store_size_bytes: _Optional[int] = ..., min_last_write_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., max_write_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., bytes_written: _Optional[_Union[MultipleWindowsStat, _Mapping]] = ...) -> None: ...
    SELF_FIELD_NUMBER: _ClassVar[int]
    PARTITIONING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    RETENTION_PERIOD_FIELD_NUMBER: _ClassVar[int]
    RETENTION_STORAGE_MB_FIELD_NUMBER: _ClassVar[int]
    SUPPORTED_CODECS_FIELD_NUMBER: _ClassVar[int]
    PARTITION_WRITE_SPEED_BYTES_PER_SECOND_FIELD_NUMBER: _ClassVar[int]
    PARTITION_TOTAL_READ_SPEED_BYTES_PER_SECOND_FIELD_NUMBER: _ClassVar[int]
    PARTITION_CONSUMER_READ_SPEED_BYTES_PER_SECOND_FIELD_NUMBER: _ClassVar[int]
    PARTITION_WRITE_BURST_BYTES_FIELD_NUMBER: _ClassVar[int]
    ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    METERING_MODE_FIELD_NUMBER: _ClassVar[int]
    TOPIC_STATS_FIELD_NUMBER: _ClassVar[int]
    self: _ydb_scheme_pb2.Entry
    partitioning_settings: PartitioningSettings
    partitions: _containers.RepeatedCompositeFieldContainer[DescribeTopicResult.PartitionInfo]
    retention_period: _duration_pb2.Duration
    retention_storage_mb: int
    supported_codecs: SupportedCodecs
    partition_write_speed_bytes_per_second: int
    partition_total_read_speed_bytes_per_second: int
    partition_consumer_read_speed_bytes_per_second: int
    partition_write_burst_bytes: int
    attributes: _containers.ScalarMap[str, str]
    consumers: _containers.RepeatedCompositeFieldContainer[Consumer]
    metering_mode: MeteringMode
    topic_stats: DescribeTopicResult.TopicStats
    def __init__(self_, self: _Optional[_Union[_ydb_scheme_pb2.Entry, _Mapping]] = ..., partitioning_settings: _Optional[_Union[PartitioningSettings, _Mapping]] = ..., partitions: _Optional[_Iterable[_Union[DescribeTopicResult.PartitionInfo, _Mapping]]] = ..., retention_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., retention_storage_mb: _Optional[int] = ..., supported_codecs: _Optional[_Union[SupportedCodecs, _Mapping]] = ..., partition_write_speed_bytes_per_second: _Optional[int] = ..., partition_total_read_speed_bytes_per_second: _Optional[int] = ..., partition_consumer_read_speed_bytes_per_second: _Optional[int] = ..., partition_write_burst_bytes: _Optional[int] = ..., attributes: _Optional[_Mapping[str, str]] = ..., consumers: _Optional[_Iterable[_Union[Consumer, _Mapping]]] = ..., metering_mode: _Optional[_Union[MeteringMode, str]] = ..., topic_stats: _Optional[_Union[DescribeTopicResult.TopicStats, _Mapping]] = ...) -> None: ...

class DescribePartitionRequest(_message.Message):
    __slots__ = ("operation_params", "path", "partition_id", "include_stats", "include_location")
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_STATS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    partition_id: int
    include_stats: bool
    include_location: bool
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ..., partition_id: _Optional[int] = ..., include_stats: bool = ..., include_location: bool = ...) -> None: ...

class DescribePartitionResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class DescribePartitionResult(_message.Message):
    __slots__ = ("partition",)
    PARTITION_FIELD_NUMBER: _ClassVar[int]
    partition: DescribeTopicResult.PartitionInfo
    def __init__(self, partition: _Optional[_Union[DescribeTopicResult.PartitionInfo, _Mapping]] = ...) -> None: ...

class DescribeConsumerRequest(_message.Message):
    __slots__ = ("operation_params", "path", "consumer", "include_stats", "include_location")
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_STATS_FIELD_NUMBER: _ClassVar[int]
    INCLUDE_LOCATION_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    consumer: str
    include_stats: bool
    include_location: bool
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ..., consumer: _Optional[str] = ..., include_stats: bool = ..., include_location: bool = ...) -> None: ...

class DescribeConsumerResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class DescribeConsumerResult(_message.Message):
    __slots__ = ("self", "consumer", "partitions")
    class PartitionInfo(_message.Message):
        __slots__ = ("partition_id", "active", "child_partition_ids", "parent_partition_ids", "partition_stats", "partition_consumer_stats", "partition_location")
        PARTITION_ID_FIELD_NUMBER: _ClassVar[int]
        ACTIVE_FIELD_NUMBER: _ClassVar[int]
        CHILD_PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
        PARENT_PARTITION_IDS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_STATS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_CONSUMER_STATS_FIELD_NUMBER: _ClassVar[int]
        PARTITION_LOCATION_FIELD_NUMBER: _ClassVar[int]
        partition_id: int
        active: bool
        child_partition_ids: _containers.RepeatedScalarFieldContainer[int]
        parent_partition_ids: _containers.RepeatedScalarFieldContainer[int]
        partition_stats: PartitionStats
        partition_consumer_stats: DescribeConsumerResult.PartitionConsumerStats
        partition_location: PartitionLocation
        def __init__(self, partition_id: _Optional[int] = ..., active: bool = ..., child_partition_ids: _Optional[_Iterable[int]] = ..., parent_partition_ids: _Optional[_Iterable[int]] = ..., partition_stats: _Optional[_Union[PartitionStats, _Mapping]] = ..., partition_consumer_stats: _Optional[_Union[DescribeConsumerResult.PartitionConsumerStats, _Mapping]] = ..., partition_location: _Optional[_Union[PartitionLocation, _Mapping]] = ...) -> None: ...
    class PartitionConsumerStats(_message.Message):
        __slots__ = ("last_read_offset", "committed_offset", "read_session_id", "partition_read_session_create_time", "last_read_time", "max_read_time_lag", "max_write_time_lag", "max_committed_time_lag", "bytes_read", "reader_name", "connection_node_id")
        LAST_READ_OFFSET_FIELD_NUMBER: _ClassVar[int]
        COMMITTED_OFFSET_FIELD_NUMBER: _ClassVar[int]
        READ_SESSION_ID_FIELD_NUMBER: _ClassVar[int]
        PARTITION_READ_SESSION_CREATE_TIME_FIELD_NUMBER: _ClassVar[int]
        LAST_READ_TIME_FIELD_NUMBER: _ClassVar[int]
        MAX_READ_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        MAX_WRITE_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        MAX_COMMITTED_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
        BYTES_READ_FIELD_NUMBER: _ClassVar[int]
        READER_NAME_FIELD_NUMBER: _ClassVar[int]
        CONNECTION_NODE_ID_FIELD_NUMBER: _ClassVar[int]
        last_read_offset: int
        committed_offset: int
        read_session_id: str
        partition_read_session_create_time: _timestamp_pb2.Timestamp
        last_read_time: _timestamp_pb2.Timestamp
        max_read_time_lag: _duration_pb2.Duration
        max_write_time_lag: _duration_pb2.Duration
        max_committed_time_lag: _duration_pb2.Duration
        bytes_read: MultipleWindowsStat
        reader_name: str
        connection_node_id: int
        def __init__(self, last_read_offset: _Optional[int] = ..., committed_offset: _Optional[int] = ..., read_session_id: _Optional[str] = ..., partition_read_session_create_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_read_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., max_read_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_write_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., max_committed_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., bytes_read: _Optional[_Union[MultipleWindowsStat, _Mapping]] = ..., reader_name: _Optional[str] = ..., connection_node_id: _Optional[int] = ...) -> None: ...
    SELF_FIELD_NUMBER: _ClassVar[int]
    CONSUMER_FIELD_NUMBER: _ClassVar[int]
    PARTITIONS_FIELD_NUMBER: _ClassVar[int]
    self: _ydb_scheme_pb2.Entry
    consumer: Consumer
    partitions: _containers.RepeatedCompositeFieldContainer[DescribeConsumerResult.PartitionInfo]
    def __init__(self_, self: _Optional[_Union[_ydb_scheme_pb2.Entry, _Mapping]] = ..., consumer: _Optional[_Union[Consumer, _Mapping]] = ..., partitions: _Optional[_Iterable[_Union[DescribeConsumerResult.PartitionInfo, _Mapping]]] = ...) -> None: ...

class PartitionStats(_message.Message):
    __slots__ = ("partition_offsets", "store_size_bytes", "last_write_time", "max_write_time_lag", "bytes_written", "partition_node_id")
    PARTITION_OFFSETS_FIELD_NUMBER: _ClassVar[int]
    STORE_SIZE_BYTES_FIELD_NUMBER: _ClassVar[int]
    LAST_WRITE_TIME_FIELD_NUMBER: _ClassVar[int]
    MAX_WRITE_TIME_LAG_FIELD_NUMBER: _ClassVar[int]
    BYTES_WRITTEN_FIELD_NUMBER: _ClassVar[int]
    PARTITION_NODE_ID_FIELD_NUMBER: _ClassVar[int]
    partition_offsets: OffsetsRange
    store_size_bytes: int
    last_write_time: _timestamp_pb2.Timestamp
    max_write_time_lag: _duration_pb2.Duration
    bytes_written: MultipleWindowsStat
    partition_node_id: int
    def __init__(self, partition_offsets: _Optional[_Union[OffsetsRange, _Mapping]] = ..., store_size_bytes: _Optional[int] = ..., last_write_time: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., max_write_time_lag: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., bytes_written: _Optional[_Union[MultipleWindowsStat, _Mapping]] = ..., partition_node_id: _Optional[int] = ...) -> None: ...

class AlterTopicRequest(_message.Message):
    __slots__ = ("operation_params", "path", "alter_partitioning_settings", "set_retention_period", "set_retention_storage_mb", "set_supported_codecs", "set_partition_write_speed_bytes_per_second", "set_partition_write_burst_bytes", "alter_attributes", "add_consumers", "drop_consumers", "alter_consumers", "set_metering_mode")
    class AlterAttributesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    ALTER_PARTITIONING_SETTINGS_FIELD_NUMBER: _ClassVar[int]
    SET_RETENTION_PERIOD_FIELD_NUMBER: _ClassVar[int]
    SET_RETENTION_STORAGE_MB_FIELD_NUMBER: _ClassVar[int]
    SET_SUPPORTED_CODECS_FIELD_NUMBER: _ClassVar[int]
    SET_PARTITION_WRITE_SPEED_BYTES_PER_SECOND_FIELD_NUMBER: _ClassVar[int]
    SET_PARTITION_WRITE_BURST_BYTES_FIELD_NUMBER: _ClassVar[int]
    ALTER_ATTRIBUTES_FIELD_NUMBER: _ClassVar[int]
    ADD_CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    DROP_CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    ALTER_CONSUMERS_FIELD_NUMBER: _ClassVar[int]
    SET_METERING_MODE_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    alter_partitioning_settings: AlterPartitioningSettings
    set_retention_period: _duration_pb2.Duration
    set_retention_storage_mb: int
    set_supported_codecs: SupportedCodecs
    set_partition_write_speed_bytes_per_second: int
    set_partition_write_burst_bytes: int
    alter_attributes: _containers.ScalarMap[str, str]
    add_consumers: _containers.RepeatedCompositeFieldContainer[Consumer]
    drop_consumers: _containers.RepeatedScalarFieldContainer[str]
    alter_consumers: _containers.RepeatedCompositeFieldContainer[AlterConsumer]
    set_metering_mode: MeteringMode
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ..., alter_partitioning_settings: _Optional[_Union[AlterPartitioningSettings, _Mapping]] = ..., set_retention_period: _Optional[_Union[datetime.timedelta, _duration_pb2.Duration, _Mapping]] = ..., set_retention_storage_mb: _Optional[int] = ..., set_supported_codecs: _Optional[_Union[SupportedCodecs, _Mapping]] = ..., set_partition_write_speed_bytes_per_second: _Optional[int] = ..., set_partition_write_burst_bytes: _Optional[int] = ..., alter_attributes: _Optional[_Mapping[str, str]] = ..., add_consumers: _Optional[_Iterable[_Union[Consumer, _Mapping]]] = ..., drop_consumers: _Optional[_Iterable[str]] = ..., alter_consumers: _Optional[_Iterable[_Union[AlterConsumer, _Mapping]]] = ..., set_metering_mode: _Optional[_Union[MeteringMode, str]] = ...) -> None: ...

class AlterTopicResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class AlterTopicResult(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class DropTopicRequest(_message.Message):
    __slots__ = ("operation_params", "path")
    OPERATION_PARAMS_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    operation_params: _ydb_operation_pb2.OperationParams
    path: str
    def __init__(self, operation_params: _Optional[_Union[_ydb_operation_pb2.OperationParams, _Mapping]] = ..., path: _Optional[str] = ...) -> None: ...

class DropTopicResponse(_message.Message):
    __slots__ = ("operation",)
    OPERATION_FIELD_NUMBER: _ClassVar[int]
    operation: _ydb_operation_pb2.Operation
    def __init__(self, operation: _Optional[_Union[_ydb_operation_pb2.Operation, _Mapping]] = ...) -> None: ...

class DropTopicResult(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



import abc
import enum
import typing

from .common_utils import IFromProto, IToProto

# Workaround for good IDE and universal for runtime
if typing.TYPE_CHECKING:
    from ..v4.protos import ydb_query_pb2, ydb_formats_pb2
else:
    from ..common.protos import ydb_query_pb2, ydb_formats_pb2


class BaseQueryTxMode(IToProto):
    """Abstract class for Query Transaction Modes."""

    @property
    @abc.abstractmethod
    def name(self) -> str:
        pass


class QuerySnapshotReadOnly(BaseQueryTxMode):
    """All the read operations within a transaction access the database snapshot.
    All the data reads are consistent. The snapshot is taken when the transaction begins,
    meaning the transaction sees all changes committed before it began.
    """

    def __init__(self):
        self._name = "snapshot_read_only"

    @property
    def name(self) -> str:
        return self._name

    def to_proto(self) -> ydb_query_pb2.SnapshotModeSettings:
        return ydb_query_pb2.SnapshotModeSettings()


class QuerySnapshotReadWrite(BaseQueryTxMode):
    def __init__(self):
        self._name = "snapshot_read_write"

    @property
    def name(self) -> str:
        return self._name

    def to_proto(self) -> ydb_query_pb2.SnapshotRWModeSettings:
        return ydb_query_pb2.SnapshotRWModeSettings()


class QuerySerializableReadWrite(BaseQueryTxMode):
    """This mode guarantees that the result of successful parallel transactions is equivalent
    to their serial execution, and there are no read anomalies for successful transactions.
    """

    def __init__(self):
        self._name = "serializable_read_write"

    @property
    def name(self) -> str:
        return self._name

    def to_proto(self) -> ydb_query_pb2.SerializableModeSettings:
        return ydb_query_pb2.SerializableModeSettings()


class QueryOnlineReadOnly(BaseQueryTxMode):
    """Each read operation in the transaction is reading the data that is most recent at execution time.
    The consistency of retrieved data depends on the allow_inconsistent_reads setting:
        * false (consistent reads): Each individual read operation returns consistent data,
          but no consistency is guaranteed between reads.
          Reading the same table range twice may return different results.
        * true (inconsistent reads): Even the data fetched by a particular
          read operation may contain inconsistent results.
    """

    def __init__(self, allow_inconsistent_reads: bool = False):
        self.allow_inconsistent_reads = allow_inconsistent_reads
        self._name = "online_read_only"

    @property
    def name(self):
        return self._name

    def with_allow_inconsistent_reads(self) -> "QueryOnlineReadOnly":
        self.allow_inconsistent_reads = True
        return self

    def to_proto(self) -> ydb_query_pb2.OnlineModeSettings:
        return ydb_query_pb2.OnlineModeSettings(allow_inconsistent_reads=self.allow_inconsistent_reads)


class QueryStaleReadOnly(BaseQueryTxMode):
    """Read operations within a transaction may return results that are slightly out-of-date
    (lagging by fractions of a second). Each individual read returns consistent data,
    but no consistency between different reads is guaranteed.
    """

    def __init__(self):
        self._name = "stale_read_only"

    @property
    def name(self):
        return self._name

    def to_proto(self) -> ydb_query_pb2.StaleModeSettings:
        return ydb_query_pb2.StaleModeSettings()


class ArrowCompressionCodecType(enum.IntEnum):
    UNSPECIFIED = 0
    NONE = 1
    ZSTD = 2
    LZ4_FRAME = 3


class ArrowCompressionCodec(IToProto):
    """Compression codec for Arrow format result sets."""

    def __init__(
        self, codec_type: typing.Optional[ArrowCompressionCodecType] = None, level: typing.Optional[int] = None
    ):
        self.type = codec_type if codec_type is not None else ArrowCompressionCodecType.UNSPECIFIED
        self.level = level

    def to_proto(self):
        return ydb_formats_pb2.ArrowFormatSettings.CompressionCodec(type=self.type, level=self.level)


class ArrowFormatSettings(IToProto):
    """Settings for Arrow format result sets."""

    def __init__(self, compression_codec: typing.Optional[ArrowCompressionCodec] = None):
        self.compression_codec = compression_codec

    def to_proto(self):
        settings = ydb_formats_pb2.ArrowFormatSettings()
        if self.compression_codec is not None:
            codec_proto = self.compression_codec.to_proto()
            settings.compression_codec.CopyFrom(codec_proto)
        return settings


class ArrowFormatMeta(IFromProto):
    """Metadata for Arrow format result sets containing the schema."""

    def __init__(self, schema: bytes):
        self.schema = schema

    @classmethod
    def from_proto(cls, proto_message):
        return cls(schema=proto_message.schema)

    def __repr__(self):
        return f"ArrowFormatMeta(schema_size={len(self.schema)} bytes)"



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_coordination.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v5.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v5.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v5.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v5.protos import ydb_scheme_pb2 as protos_dot_ydb__scheme__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dprotos/ydb_coordination.proto\x12\x10Ydb.Coordination\x1a\x1aprotos/ydb_operation.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x17protos/ydb_scheme.proto\"\r\n\x0bUnsupported\"\xb2\x02\n\x06\x43onfig\x12\x0c\n\x04path\x18\x01 \x01(\t\x12 \n\x18self_check_period_millis\x18\x02 \x01(\r\x12#\n\x1bsession_grace_period_millis\x18\x03 \x01(\r\x12@\n\x15read_consistency_mode\x18\x04 \x01(\x0e\x32!.Ydb.Coordination.ConsistencyMode\x12\x42\n\x17\x61ttach_consistency_mode\x18\x05 \x01(\x0e\x32!.Ydb.Coordination.ConsistencyMode\x12M\n\x1arate_limiter_counters_mode\x18\x06 \x01(\x0e\x32).Ydb.Coordination.RateLimiterCountersMode\"g\n\x12SessionDescription\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x61ttached\x18\x04 \x01(\x08\"m\n\x10SemaphoreSession\x12\x10\n\x08order_id\x18\x05 \x01(\x04\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x12\r\n\x05\x63ount\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\"\xcc\x01\n\x14SemaphoreDescription\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\r\n\x05\x63ount\x18\x07 \x01(\x04\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x11\n\tephemeral\x18\x04 \x01(\x08\x12\x32\n\x06owners\x18\x05 \x03(\x0b\x32\".Ydb.Coordination.SemaphoreSession\x12\x33\n\x07waiters\x18\x06 \x03(\x0b\x32\".Ydb.Coordination.SemaphoreSession\"\xd1\r\n\x0eSessionRequest\x12\x39\n\x04ping\x18\x01 \x01(\x0b\x32).Ydb.Coordination.SessionRequest.PingPongH\x00\x12\x39\n\x04pong\x18\x02 \x01(\x0b\x32).Ydb.Coordination.SessionRequest.PingPongH\x00\x12\x46\n\rsession_start\x18\x03 \x01(\x0b\x32-.Ydb.Coordination.SessionRequest.SessionStartH\x00\x12\x44\n\x0csession_stop\x18\x04 \x01(\x0b\x32,.Ydb.Coordination.SessionRequest.SessionStopH\x00\x12\x36\n\runsupported_5\x18\x05 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x36\n\runsupported_6\x18\x06 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12N\n\x11\x61\x63quire_semaphore\x18\x07 \x01(\x0b\x32\x31.Ydb.Coordination.SessionRequest.AcquireSemaphoreH\x00\x12N\n\x11release_semaphore\x18\x08 \x01(\x0b\x32\x31.Ydb.Coordination.SessionRequest.ReleaseSemaphoreH\x00\x12P\n\x12\x64\x65scribe_semaphore\x18\t \x01(\x0b\x32\x32.Ydb.Coordination.SessionRequest.DescribeSemaphoreH\x00\x12L\n\x10\x63reate_semaphore\x18\n \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.CreateSemaphoreH\x00\x12L\n\x10update_semaphore\x18\x0b \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.UpdateSemaphoreH\x00\x12L\n\x10\x64\x65lete_semaphore\x18\x0c \x01(\x0b\x32\x30.Ydb.Coordination.SessionRequest.DeleteSemaphoreH\x00\x12\x37\n\x0eunsupported_13\x18\r \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_14\x18\x0e \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_15\x18\x0f \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x1a\x1a\n\x08PingPong\x12\x0e\n\x06opaque\x18\x01 \x01(\x04\x1a\x85\x01\n\x0cSessionStart\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x03 \x01(\x04\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x0e\n\x06seq_no\x18\x05 \x01(\x04\x12\x16\n\x0eprotection_key\x18\x06 \x01(\x0c\x1a\r\n\x0bSessionStop\x1ax\n\x10\x41\x63quireSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0etimeout_millis\x18\x03 \x01(\x04\x12\r\n\x05\x63ount\x18\x04 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x11\n\tephemeral\x18\x06 \x01(\x08\x1a\x30\n\x10ReleaseSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x1a\x8c\x01\n\x11\x44\x65scribeSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x16\n\x0einclude_owners\x18\x03 \x01(\x08\x12\x17\n\x0finclude_waiters\x18\x04 \x01(\x08\x12\x12\n\nwatch_data\x18\x05 \x01(\x08\x12\x14\n\x0cwatch_owners\x18\x06 \x01(\x08\x1aL\n\x0f\x43reateSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x04\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x0c\x1a=\n\x0fUpdateSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x1a>\n\x0f\x44\x65leteSemaphore\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x66orce\x18\x03 \x01(\x08\x42\t\n\x07request\"\xd3\x14\n\x0fSessionResponse\x12:\n\x04ping\x18\x01 \x01(\x0b\x32*.Ydb.Coordination.SessionResponse.PingPongH\x00\x12:\n\x04pong\x18\x02 \x01(\x0b\x32*.Ydb.Coordination.SessionResponse.PingPongH\x00\x12<\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32).Ydb.Coordination.SessionResponse.FailureH\x00\x12K\n\x0fsession_started\x18\x04 \x01(\x0b\x32\x30.Ydb.Coordination.SessionResponse.SessionStartedH\x00\x12K\n\x0fsession_stopped\x18\x05 \x01(\x0b\x32\x30.Ydb.Coordination.SessionResponse.SessionStoppedH\x00\x12\x36\n\runsupported_6\x18\x06 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x36\n\runsupported_7\x18\x07 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12^\n\x19\x61\x63quire_semaphore_pending\x18\x08 \x01(\x0b\x32\x39.Ydb.Coordination.SessionResponse.AcquireSemaphorePendingH\x00\x12\\\n\x18\x61\x63quire_semaphore_result\x18\t \x01(\x0b\x32\x38.Ydb.Coordination.SessionResponse.AcquireSemaphoreResultH\x00\x12\\\n\x18release_semaphore_result\x18\n \x01(\x0b\x32\x38.Ydb.Coordination.SessionResponse.ReleaseSemaphoreResultH\x00\x12^\n\x19\x64\x65scribe_semaphore_result\x18\x0b \x01(\x0b\x32\x39.Ydb.Coordination.SessionResponse.DescribeSemaphoreResultH\x00\x12`\n\x1a\x64\x65scribe_semaphore_changed\x18\x0c \x01(\x0b\x32:.Ydb.Coordination.SessionResponse.DescribeSemaphoreChangedH\x00\x12Z\n\x17\x63reate_semaphore_result\x18\r \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.CreateSemaphoreResultH\x00\x12Z\n\x17update_semaphore_result\x18\x0e \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.UpdateSemaphoreResultH\x00\x12Z\n\x17\x64\x65lete_semaphore_result\x18\x0f \x01(\x0b\x32\x37.Ydb.Coordination.SessionResponse.DeleteSemaphoreResultH\x00\x12\x37\n\x0eunsupported_16\x18\x10 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_17\x18\x11 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x12\x37\n\x0eunsupported_18\x18\x12 \x01(\x0b\x32\x1d.Ydb.Coordination.UnsupportedH\x00\x1a\x1a\n\x08PingPong\x12\x0e\n\x06opaque\x18\x01 \x01(\x04\x1a]\n\x07\x46\x61ilure\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a<\n\x0eSessionStarted\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x12\x16\n\x0etimeout_millis\x18\x02 \x01(\x04\x1a$\n\x0eSessionStopped\x12\x12\n\nsession_id\x18\x01 \x01(\x04\x1a)\n\x17\x41\x63quireSemaphorePending\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x1a\x8e\x01\n\x16\x41\x63quireSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x10\n\x08\x61\x63quired\x18\x04 \x01(\x08\x1a\x8e\x01\n\x16ReleaseSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x10\n\x08released\x18\x04 \x01(\x08\x1a\xd9\x01\n\x17\x44\x65scribeSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x45\n\x15semaphore_description\x18\x04 \x01(\x0b\x32&.Ydb.Coordination.SemaphoreDescription\x12\x13\n\x0bwatch_added\x18\x05 \x01(\x08\x1aX\n\x18\x44\x65scribeSemaphoreChanged\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12\x14\n\x0c\x64\x61ta_changed\x18\x02 \x01(\x08\x12\x16\n\x0eowners_changed\x18\x03 \x01(\x08\x1a{\n\x15\x43reateSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a{\n\x15UpdateSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x1a{\n\x15\x44\x65leteSemaphoreResult\x12\x0e\n\x06req_id\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessageB\n\n\x08response\"\x86\x01\n\x11\x43reateNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"B\n\x12\x43reateNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x85\x01\n\x10\x41lterNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x39\n\x10operation_params\x18\x03 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11\x41lterNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Z\n\x0f\x44ropNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"@\n\x10\x44ropNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"^\n\x13\x44\x65scribeNodeRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x39\n\x10operation_params\x18\x02 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"D\n\x14\x44\x65scribeNodeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x12\x44\x65scribeNodeResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12(\n\x06\x63onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config*h\n\x0f\x43onsistencyMode\x12\x1a\n\x16\x43ONSISTENCY_MODE_UNSET\x10\x00\x12\x1b\n\x17\x43ONSISTENCY_MODE_STRICT\x10\x01\x12\x1c\n\x18\x43ONSISTENCY_MODE_RELAXED\x10\x02*\x93\x01\n\x17RateLimiterCountersMode\x12$\n RATE_LIMITER_COUNTERS_MODE_UNSET\x10\x00\x12)\n%RATE_LIMITER_COUNTERS_MODE_AGGREGATED\x10\x01\x12\'\n#RATE_LIMITER_COUNTERS_MODE_DETAILED\x10\x02\x42w\n\x1btech.ydb.proto.coordinationB\x12\x43oordinationProtosP\x01Z?github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Coordination\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'protos.ydb_coordination_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033tech.ydb.proto.coordinationB\022CoordinationProtosP\001Z?github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Coordination\370\001\001'
  _CONSISTENCYMODE._serialized_start=6137
  _CONSISTENCYMODE._serialized_end=6241
  _RATELIMITERCOUNTERSMODE._serialized_start=6244
  _RATELIMITERCOUNTERSMODE._serialized_end=6391
  _UNSUPPORTED._serialized_start=167
  _UNSUPPORTED._serialized_end=180
  _CONFIG._serialized_start=183
  _CONFIG._serialized_end=489
  _SESSIONDESCRIPTION._serialized_start=491
  _SESSIONDESCRIPTION._serialized_end=594
  _SEMAPHORESESSION._serialized_start=596
  _SEMAPHORESESSION._serialized_end=705
  _SEMAPHOREDESCRIPTION._serialized_start=708
  _SEMAPHOREDESCRIPTION._serialized_end=912
  _SESSIONREQUEST._serialized_start=915
  _SESSIONREQUEST._serialized_end=2660
  _SESSIONREQUEST_PINGPONG._serialized_start=1952
  _SESSIONREQUEST_PINGPONG._serialized_end=1978
  _SESSIONREQUEST_SESSIONSTART._serialized_start=1981
  _SESSIONREQUEST_SESSIONSTART._serialized_end=2114
  _SESSIONREQUEST_SESSIONSTOP._serialized_start=2116
  _SESSIONREQUEST_SESSIONSTOP._serialized_end=2129
  _SESSIONREQUEST_ACQUIRESEMAPHORE._serialized_start=2131
  _SESSIONREQUEST_ACQUIRESEMAPHORE._serialized_end=2251
  _SESSIONREQUEST_RELEASESEMAPHORE._serialized_start=2253
  _SESSIONREQUEST_RELEASESEMAPHORE._serialized_end=2301
  _SESSIONREQUEST_DESCRIBESEMAPHORE._serialized_start=2304
  _SESSIONREQUEST_DESCRIBESEMAPHORE._serialized_end=2444
  _SESSIONREQUEST_CREATESEMAPHORE._serialized_start=2446
  _SESSIONREQUEST_CREATESEMAPHORE._serialized_end=2522
  _SESSIONREQUEST_UPDATESEMAPHORE._serialized_start=2524
  _SESSIONREQUEST_UPDATESEMAPHORE._serialized_end=2585
  _SESSIONREQUEST_DELETESEMAPHORE._serialized_start=2587
  _SESSIONREQUEST_DELETESEMAPHORE._serialized_end=2649
  _SESSIONRESPONSE._serialized_start=2663
  _SESSIONRESPONSE._serialized_end=5306
  _SESSIONRESPONSE_PINGPONG._serialized_start=1952
  _SESSIONRESPONSE_PINGPONG._serialized_end=1978
  _SESSIONRESPONSE_FAILURE._serialized_start=4083
  _SESSIONRESPONSE_FAILURE._serialized_end=4176
  _SESSIONRESPONSE_SESSIONSTARTED._serialized_start=4178
  _SESSIONRESPONSE_SESSIONSTARTED._serialized_end=4238
  _SESSIONRESPONSE_SESSIONSTOPPED._serialized_start=4240
  _SESSIONRESPONSE_SESSIONSTOPPED._serialized_end=4276
  _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING._serialized_start=4278
  _SESSIONRESPONSE_ACQUIRESEMAPHOREPENDING._serialized_end=4319
  _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT._serialized_start=4322
  _SESSIONRESPONSE_ACQUIRESEMAPHORERESULT._serialized_end=4464
  _SESSIONRESPONSE_RELEASESEMAPHORERESULT._serialized_start=4467
  _SESSIONRESPONSE_RELEASESEMAPHORERESULT._serialized_end=4609
  _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT._serialized_start=4612
  _SESSIONRESPONSE_DESCRIBESEMAPHORERESULT._serialized_end=4829
  _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED._serialized_start=4831
  _SESSIONRESPONSE_DESCRIBESEMAPHORECHANGED._serialized_end=4919
  _SESSIONRESPONSE_CREATESEMAPHORERESULT._serialized_start=4921
  _SESSIONRESPONSE_CREATESEMAPHORERESULT._serialized_end=5044
  _SESSIONRESPONSE_UPDATESEMAPHORERESULT._serialized_start=5046
  _SESSIONRESPONSE_UPDATESEMAPHORERESULT._serialized_end=5169
  _SESSIONRESPONSE_DELETESEMAPHORERESULT._serialized_start=5171
  _SESSIONRESPONSE_DELETESEMAPHORERESULT._serialized_end=5294
  _CREATENODEREQUEST._serialized_start=5309
  _CREATENODEREQUEST._serialized_end=5443
  _CREATENODERESPONSE._serialized_start=5445
  _CREATENODERESPONSE._serialized_end=5511
  _ALTERNODEREQUEST._serialized_start=5514
  _ALTERNODEREQUEST._serialized_end=5647
  _ALTERNODERESPONSE._serialized_start=5649
  _ALTERNODERESPONSE._serialized_end=5714
  _DROPNODEREQUEST._serialized_start=5716
  _DROPNODEREQUEST._serialized_end=5806
  _DROPNODERESPONSE._serialized_start=5808
  _DROPNODERESPONSE._serialized_end=5872
  _DESCRIBENODEREQUEST._serialized_start=5874
  _DESCRIBENODEREQUEST._serialized_end=5968
  _DESCRIBENODERESPONSE._serialized_start=5970
  _DESCRIBENODERESPONSE._serialized_end=6038
  _DESCRIBENODERESULT._serialized_start=6040
  _DESCRIBENODERESULT._serialized_end=6135
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: draft/protos/ydb_dynamic_config.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'draft/protos/ydb_dynamic_config.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v6.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%draft/protos/ydb_dynamic_config.proto\x12\x11Ydb.DynamicConfig\x1a\x1aprotos/ydb_operation.proto\"2\n\x0e\x43onfigIdentity\x12\x0f\n\x07version\x18\x01 \x01(\x04\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\"\x8c\x01\n\x10SetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"A\n\x11SetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x90\x01\n\x14ReplaceConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x03 \x01(\x08\x12\x1c\n\x14\x61llow_unknown_fields\x18\x04 \x01(\x08\"E\n\x15ReplaceConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x83\x01\n\x11\x44ropConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x33\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"B\n\x12\x44ropConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x18\x41\x64\x64VolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"I\n\x19\x41\x64\x64VolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\",\n\x0eVolatileConfig\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"M\n\x10GetConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"A\n\x11GetConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x93\x01\n\x0fGetConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12;\n\x10volatile_configs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x33\n\x08identity\x18\x03 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentity\"6\n\x16VolatileConfigMetadata\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x10\n\x08metadata\x18\x02 \x01(\t\"O\n\x12GetMetadataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"C\n\x13GetMetadataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"j\n\x11GetMetadataResult\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x43\n\x10volatile_configs\x18\x02 \x03(\x0b\x32).Ydb.DynamicConfig.VolatileConfigMetadata\"\xb7\x02\n\x1bRemoveVolatileConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x35\n\x08identity\x18\x02 \x01(\x0b\x32!.Ydb.DynamicConfig.ConfigIdentityH\x00\x12\x0f\n\x05\x66orce\x18\x03 \x01(\x08H\x00\x12I\n\x03ids\x18\x04 \x01(\x0b\x32:.Ydb.DynamicConfig.RemoveVolatileConfigRequest.IdsToDeleteH\x01\x12\r\n\x03\x61ll\x18\x05 \x01(\x08H\x01\x1a\x1a\n\x0bIdsToDelete\x12\x0b\n\x03ids\x18\x01 \x03(\x04\x42\x13\n\x11\x63onsistency_checkB\n\n\x08selector\"L\n\x1cRemoveVolatileConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x14GetNodeLabelsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0f\n\x07node_id\x18\x02 \x01(\r\")\n\tYamlLabel\x12\r\n\x05label\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"E\n\x15GetNodeLabelsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"C\n\x13GetNodeLabelsResult\x12,\n\x06labels\x18\x01 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"\xcc\x01\n\x14ResolveConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12,\n\x06labels\x18\x04 \x03(\x0b\x32\x1c.Ydb.DynamicConfig.YamlLabel\"E\n\x15ResolveConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"%\n\x13ResolveConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\"\xbb\x01\n\x17ResolveAllConfigRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\x12;\n\x10volatile_configs\x18\x03 \x03(\x0b\x32!.Ydb.DynamicConfig.VolatileConfig\x12\x18\n\x10verbose_response\x18\x04 \x01(\x08\"\xb6\x01\n\x0cYamlLabelExt\x12\r\n\x05label\x18\x01 \x01(\t\x12\x37\n\x04type\x18\x02 \x01(\x0e\x32).Ydb.DynamicConfig.YamlLabelExt.LabelType\x12\x12\n\x05value\x18\x03 \x01(\tH\x00\x88\x01\x01\"@\n\tLabelType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06\x43OMMON\x10\x01\x12\x0b\n\x07NOT_SET\x10\x02\x12\t\n\x05\x45MPTY\x10\x03\x42\x08\n\x06_value\";\n\x08LabelSet\x12/\n\x06labels\x18\x01 \x03(\x0b\x32\x1f.Ydb.DynamicConfig.YamlLabelExt\"Q\n\x0eResolvedConfig\x12/\n\nlabel_sets\x18\x01 \x03(\x0b\x32\x1b.Ydb.DynamicConfig.LabelSet\x12\x0e\n\x06\x63onfig\x18\x02 \x01(\t\"H\n\x18ResolveAllConfigResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\\\n\x16ResolveAllConfigResult\x12\x0e\n\x06\x63onfig\x18\x01 \x01(\t\x12\x32\n\x07\x63onfigs\x18\x02 \x03(\x0b\x32!.Ydb.DynamicConfig.ResolvedConfigBo\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\xf8\x01\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'draft.protos.ydb_dynamic_config_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"tech.ydb.proto.draft.dynamicconfigZFgithub.com/ydb-platform/ydb-go-genproto/draft/protos/Ydb_DynamicConfig\370\001\001'
  _globals['_CONFIGIDENTITY']._serialized_start=88
  _globals['_CONFIGIDENTITY']._serialized_end=138
  _globals['_SETCONFIGREQUEST']._serialized_start=141
  _globals['_SETCONFIGREQUEST']._serialized_end=281
  _globals['_SETCONFIGRESPONSE']._serialized_start=283
  _globals['_SETCONFIGRESPONSE']._serialized_end=348
  _globals['_REPLACECONFIGREQUEST']._serialized_start=351
  _globals['_REPLACECONFIGREQUEST']._serialized_end=495
  _globals['_REPLACECONFIGRESPONSE']._serialized_start=497
  _globals['_REPLACECONFIGRESPONSE']._serialized_end=566
  _globals['_DROPCONFIGREQUEST']._serialized_start=569
  _globals['_DROPCONFIGREQUEST']._serialized_end=700
  _globals['_DROPCONFIGRESPONSE']._serialized_start=702
  _globals['_DROPCONFIGRESPONSE']._serialized_end=768
  _globals['_ADDVOLATILECONFIGREQUEST']._serialized_start=770
  _globals['_ADDVOLATILECONFIGREQUEST']._serialized_end=871
  _globals['_ADDVOLATILECONFIGRESPONSE']._serialized_start=873
  _globals['_ADDVOLATILECONFIGRESPONSE']._serialized_end=946
  _globals['_VOLATILECONFIG']._serialized_start=948
  _globals['_VOLATILECONFIG']._serialized_end=992
  _globals['_GETCONFIGREQUEST']._serialized_start=994
  _globals['_GETCONFIGREQUEST']._serialized_end=1071
  _globals['_GETCONFIGRESPONSE']._serialized_start=1073
  _globals['_GETCONFIGRESPONSE']._serialized_end=1138
  _globals['_GETCONFIGRESULT']._serialized_start=1141
  _globals['_GETCONFIGRESULT']._serialized_end=1288
  _globals['_VOLATILECONFIGMETADATA']._serialized_start=1290
  _globals['_VOLATILECONFIGMETADATA']._serialized_end=1344
  _globals['_GETMETADATAREQUEST']._serialized_start=1346
  _globals['_GETMETADATAREQUEST']._serialized_end=1425
  _globals['_GETMETADATARESPONSE']._serialized_start=1427
  _globals['_GETMETADATARESPONSE']._serialized_end=1494
  _globals['_GETMETADATARESULT']._serialized_start=1496
  _globals['_GETMETADATARESULT']._serialized_end=1602
  _globals['_REMOVEVOLATILECONFIGREQUEST']._serialized_start=1605
  _globals['_REMOVEVOLATILECONFIGREQUEST']._serialized_end=1916
  _globals['_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE']._serialized_start=1857
  _globals['_REMOVEVOLATILECONFIGREQUEST_IDSTODELETE']._serialized_end=1883
  _globals['_REMOVEVOLATILECONFIGRESPONSE']._serialized_start=1918
  _globals['_REMOVEVOLATILECONFIGRESPONSE']._serialized_end=1994
  _globals['_GETNODELABELSREQUEST']._serialized_start=1996
  _globals['_GETNODELABELSREQUEST']._serialized_end=2094
  _globals['_YAMLLABEL']._serialized_start=2096
  _globals['_YAMLLABEL']._serialized_end=2137
  _globals['_GETNODELABELSRESPONSE']._serialized_start=2139
  _globals['_GETNODELABELSRESPONSE']._serialized_end=2208
  _globals['_GETNODELABELSRESULT']._serialized_start=2210
  _globals['_GETNODELABELSRESULT']._serialized_end=2277
  _globals['_RESOLVECONFIGREQUEST']._serialized_start=2280
  _globals['_RESOLVECONFIGREQUEST']._serialized_end=2484
  _globals['_RESOLVECONFIGRESPONSE']._serialized_start=2486
  _globals['_RESOLVECONFIGRESPONSE']._serialized_end=2555
  _globals['_RESOLVECONFIGRESULT']._serialized_start=2557
  _globals['_RESOLVECONFIGRESULT']._serialized_end=2594
  _globals['_RESOLVEALLCONFIGREQUEST']._serialized_start=2597
  _globals['_RESOLVEALLCONFIGREQUEST']._serialized_end=2784
  _globals['_YAMLLABELEXT']._serialized_start=2787
  _globals['_YAMLLABELEXT']._serialized_end=2969
  _globals['_YAMLLABELEXT_LABELTYPE']._serialized_start=2895
  _globals['_YAMLLABELEXT_LABELTYPE']._serialized_end=2959
  _globals['_LABELSET']._serialized_start=2971
  _globals['_LABELSET']._serialized_end=3030
  _globals['_RESOLVEDCONFIG']._serialized_start=3032
  _globals['_RESOLVEDCONFIG']._serialized_end=3113
  _globals['_RESOLVEALLCONFIGRESPONSE']._serialized_start=3115
  _globals['_RESOLVEALLCONFIGRESPONSE']._serialized_end=3187
  _globals['_RESOLVEALLCONFIGRESULT']._serialized_start=3189
  _globals['_RESOLVEALLCONFIGRESULT']._serialized_end=3281
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb_rate_limiter_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb._grpc.v4.protos import ydb_rate_limiter_pb2 as protos_dot_ydb__rate__limiter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb_rate_limiter_v1.proto\x12\x12Ydb.RateLimiter.V1\x1a\x1dprotos/ydb_rate_limiter.proto2\xe3\x04\n\x12RateLimiterService\x12\x61\n\x0e\x43reateResource\x12&.Ydb.RateLimiter.CreateResourceRequest\x1a\'.Ydb.RateLimiter.CreateResourceResponse\x12^\n\rAlterResource\x12%.Ydb.RateLimiter.AlterResourceRequest\x1a&.Ydb.RateLimiter.AlterResourceResponse\x12[\n\x0c\x44ropResource\x12$.Ydb.RateLimiter.DropResourceRequest\x1a%.Ydb.RateLimiter.DropResourceResponse\x12^\n\rListResources\x12%.Ydb.RateLimiter.ListResourcesRequest\x1a&.Ydb.RateLimiter.ListResourcesResponse\x12g\n\x10\x44\x65scribeResource\x12(.Ydb.RateLimiter.DescribeResourceRequest\x1a).Ydb.RateLimiter.DescribeResourceResponse\x12\x64\n\x0f\x41\x63quireResource\x12\'.Ydb.RateLimiter.AcquireResourceRequest\x1a(.Ydb.RateLimiter.AcquireResourceResponseBo\n\x1etech.ydb.proto.rate_limiter.v1B\x0fRateLimiterGrpcP\x01Z:github.com/ydb-platform/ydb-go-genproto/Ydb_RateLimiter_V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb_rate_limiter_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\036tech.ydb.proto.rate_limiter.v1B\017RateLimiterGrpcP\001Z:github.com/ydb-platform/ydb-go-genproto/Ydb_RateLimiter_V1'
  _RATELIMITERSERVICE._serialized_start=81
  _RATELIMITERSERVICE._serialized_end=692
# @@protoc_insertion_point(module_scope)
